'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _es6Promise = require('es6-promise');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var JsonRpcClient = function () {
    function JsonRpcClient(_ref) {
        var apiRoute = _ref.apiRoute,
            _ref$headers = _ref.headers,
            headers = _ref$headers === undefined ? {} : _ref$headers,
            withMeta = _ref.withMeta;

        _classCallCheck(this, JsonRpcClient);

        this.apiRoute = apiRoute;
        this.headers = _extends({}, JsonRpcClient.defaultHeaders, headers);
        this.withMeta = withMeta;
    }

    _createClass(JsonRpcClient, [{
        key: 'asCurl',
        value: function asCurl(method, params, id) {
            var options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : { headers: {} };

            var body = {
                jsonrpc: '2.0',
                method: method,
                params: params,
                id: id
            };

            var allHeaders = _extends({}, this.headers, options.headers);

            var headers = Object.keys(allHeaders).map(function (key) {
                return '-H \'' + key + ': ' + allHeaders[key] + '\'';
            });

            return ['curl -i', '-X POST', headers.join(' '), '--data-binary \'' + JSON.stringify(body) + '\'', '\'' + this.apiRoute + '\''].join(' ');
        }
    }, {
        key: 'request',
        value: function request(method, params) {
            var _this = this;

            var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : { headers: {} };

            this.requestId = JsonRpcClient.getUniqId();

            var body = {
                jsonrpc: '2.0',
                method: method,
                params: params,
                id: this.requestId
            };

            var startTime = new Date();

            var headers = _extends({}, this.headers, options.headers);

            return new _es6Promise.Promise(function (resolve, reject) {
                _axios2.default.post(_this.apiRoute, body, {
                    headers: headers
                }).then(function (_ref2) {
                    var res = _ref2.data;

                    if (!res) {
                        reject({ error: 'Unknown error' });
                        return;
                    }

                    if (res.error) {
                        reject({
                            error: res.error.message,
                            code: res.error.code
                        });
                        return;
                    }

                    var meta = {};

                    if (_this.withMeta) {
                        meta = {
                            curl: _this.asCurl(method, params, _this.requestId, {
                                headers: headers
                            }),
                            timeRequest: new Date() - startTime
                        };
                    }

                    resolve({ data: res.result, meta: meta });
                }).catch(function (err) {
                    if (err.response) {
                        reject({
                            error: err.response.statusText,
                            code: err.response.status
                        });
                        return;
                    }

                    reject({
                        error: 'Unknown error'
                    });
                });
            });
        }
    }]);

    return JsonRpcClient;
}();

Object.defineProperty(JsonRpcClient, 'defaultHeaders', {
    enumerable: true,
    writable: true,
    value: {
        'Content-Type': 'application/json'
    }
});
Object.defineProperty(JsonRpcClient, 'getUniqId', {
    enumerable: true,
    writable: true,
    value: function () {
        var counter = 0;

        return function () {
            counter += 1;

            if (!Number.isSafeInteger(counter)) {
                counter = 0;
            }

            return counter;
        };
    }()
});
exports.default = JsonRpcClient;